@@ -2,10 +2,7 @@ use core::convert::Infallible;
 
 /// Crypto error variants
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Hash)]
-#[cfg_attr(
-    feature = "serde-types-minimal",
-    derive(serde::Serialize, serde::Deserialize)
-)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub enum Error {
     /// Invalid secp256k1 secret key
     InvalidSecretKey,
