@@ -1,5 +1,6 @@
 //! Fuel cryptographic primitives.
 
+#![cfg_attr(docsrs, feature(doc_auto_cfg))]
 #![cfg_attr(not(feature = "std"), no_std)]
 #![warn(missing_docs)]
 // Wrong clippy convention; check
@@ -7,7 +8,15 @@
 #![allow(clippy::wrong_self_convention)]
 
 /// Required export to implement [`Keystore`].
+#[doc(no_inline)]
 pub use borrown;
+/// Required export to use various public interfaces in this crate
+#[doc(no_inline)]
+pub use fuel_types;
+#[cfg(feature = "random")]
+#[doc(no_inline)]
+/// Required export to use randomness features
+pub use rand;
 
 mod error;
 mod hasher;
